window.Gleam.initSearch([{"doc":"startest","title":"startest","content":"# startest\n\n[![Package Version](https://img.shields.io/hexpm/v/startest)](https://hex.pm/packages/startest)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/startest/)\n![Erlang-compatible](https://img.shields.io/badge/target-erlang-b83998)\n![JavaScript-compatible](https://img.shields.io/badge/target-javascript-f1e05a)\n\n🌠 A testing framework to help you shoot for the stars.\n\n## Installation\n\n```sh\ngleam add --dev startest\n```\n\n## Features\n\n- Write tests using the `describe` API or as standalone functions\n- Filter tests by file path or test name\n- Pretty assertions from `expect` matchers\n\n## Usage\n\n```gleam\nimport startest.{describe, it}\nimport startest/expect\n\n// Inside of `test/my_project_test.gleam`:\npub fn main() {\n  // Call `startest.run` inside of your `main` function.\n  // Here we&#39;re using the default config, but you can customize this, as needed.\n  startest.run(startest.default_config())\n}\n\n// Tests can be expressed using the `describe` API:\npub fn my_project_tests() {\n  describe(&quot;My Project&quot;, [\n    describe(&quot;2 + 2&quot;, [\n      it(&quot;equals 4&quot;, fn() {\n        2 + 2\n        |&gt; expect.to_equal(4)\n      }),\n    ]),\n  ])\n}\n\n// You can also write tests as standalone functions.\n// These functions must be public and have a name ending in `_test`:\npub fn a_standalone_test() {\n  { &quot;Hello, &quot; &lt;&gt; &quot;Joe!&quot; }\n  |&gt; expect.to_equal(&quot;Hello, Joe!&quot;)\n}\n```\n\n## Migrating from gleeunit\n\nIf you&#39;re coming from [`gleeunit`](https://hexdocs.pm/gleeunit), follow these steps for an easy migration to Startest:\n\n1. Install Startest with `gleam add --dev startest`\n1. Replace all imports of `gleeunit` with `startest`\n1. Replace `gleeunit.main` with `startest.run(startest.default_config())`\n1. Replace all imports of `gleeunit/should` with `startest/expect`\n1. Update `gleeunit/should` assertions to `startest/expect`\n   - Consult the migration table down below for the equivalent assertions in Startest\n1. Remove `gleeunit` with `gleam remove gleeunit`\n1. Optionally, begin using the `describe` API to structure your tests\n\n| `gleeunit/should`  | `startest/expect`                     |\n| ------------------ | ------------------------------------- |\n| `should.equal`     | `expect.to_equal`                     |\n| `should.not_equal` | `expect.to_not_equal`                 |\n| `should.be_true`   | `expect.to_be_true`                   |\n| `should.be_false`  | `expect.to_be_false`                  |\n| `should.be_ok`     | `expect.to_be_ok`                     |\n| `should.be_error`  | `expect.to_be_error`                  |\n| `should.be_some`   | `expect.to_be_some`                   |\n| `should.be_none`   | `expect.to_be_none`                   |\n| `should.fail`      | `expect.to_be_true(False)` or `panic` |\n\nThis conversion can typically be done with a find/replace:\n\n```diff\n- should.\n+ expect.to_\n```\n","url":"index.html"},{"doc":"startest/logger","title":"Logger","content":"pub type Logger {\n  Logger\n}\n\nLogger\n\n\nSynonyms:\nstartest/logger.Logger\nstartest/logger Logger","url":"startest/logger.html#Logger"},{"doc":"startest/logger","title":"error","content":"pub fn error(logger: Logger, message: String) -&gt; Nil\n\nSynonyms:\nstartest/logger.error\nstartest/logger error","url":"startest/logger.html#error"},{"doc":"startest/logger","title":"log","content":"pub fn log(logger: Logger, message: String) -&gt; Nil\n\nSynonyms:\nstartest/logger.log\nstartest/logger log","url":"startest/logger.html#log"},{"doc":"startest/logger","title":"startest/logger","content":"","url":"startest/logger.html"},{"doc":"startest/assertion_error","title":"AssertionError","content":"pub type AssertionError {\n  AssertionError(\n    message: String,\n    actual: String,\n    expected: String,\n  )\n}\n\nAssertionError(message: String, actual: String, expected: String)\n\n\nSynonyms:\nstartest/assertion_error.AssertionError\nstartest/assertion_error AssertionError","url":"startest/assertion_error.html#AssertionError"},{"doc":"startest/assertion_error","title":"RescuedAssertionError","content":"pub type RescuedAssertionError {\n  RescuedAssertionError(message: String)\n}\n\nRescuedAssertionError(message: String)\n\n\nSynonyms:\nstartest/assertion_error.RescuedAssertionError\nstartest/assertion_error RescuedAssertionError","url":"startest/assertion_error.html#RescuedAssertionError"},{"doc":"startest/assertion_error","title":"raise","content":"pub fn raise(error: AssertionError) -&gt; a\n Raises an `AssertionError`.\n\n Intended for use by matchers to cause a test to fail.\nSynonyms:\nstartest/assertion_error.raise\nstartest/assertion_error raise","url":"startest/assertion_error.html#raise"},{"doc":"startest/assertion_error","title":"startest/assertion_error","content":"","url":"startest/assertion_error.html"},{"doc":"startest/test_failure","title":"TestFailure","content":"pub type TestFailure {\n  AssertionError(RescuedAssertionError)\n  GenericError(Exception)\n}\n\nAssertionError(RescuedAssertionError)\n\n\nGenericError(Exception)\n\n\nSynonyms:\nstartest/test_failure.TestFailure\nstartest/test_failure TestFailure","url":"startest/test_failure.html#TestFailure"},{"doc":"startest/test_failure","title":"rescue","content":"pub fn rescue(f: fn() -&gt; Nil) -&gt; Result(Nil, TestFailure)\n\nSynonyms:\nstartest/test_failure.rescue\nstartest/test_failure rescue","url":"startest/test_failure.html#rescue"},{"doc":"startest/test_failure","title":"to_string","content":"pub fn to_string(failure: TestFailure) -&gt; String\n\nSynonyms:\nstartest/test_failure.to_string\nstartest/test_failure to_string","url":"startest/test_failure.html#to_string"},{"doc":"startest/test_failure","title":"startest/test_failure","content":"","url":"startest/test_failure.html"},{"doc":"startest/test_case","title":"ExecutedTest","content":"pub type ExecutedTest {\n  ExecutedTest(test_case: Test, outcome: TestOutcome)\n}\n A `Test` that has been executed and has a `TestOutcome`.\nExecutedTest(test_case: Test, outcome: TestOutcome)\n\n\nSynonyms:\nstartest/test_case.ExecutedTest\nstartest/test_case ExecutedTest","url":"startest/test_case.html#ExecutedTest"},{"doc":"startest/test_case","title":"Test","content":"pub type Test {\n  Test(name: String, body: TestBody, skipped: Bool)\n}\n A test case.\nTest(name: String, body: TestBody, skipped: Bool)\n\n\nSynonyms:\nstartest/test_case.Test\nstartest/test_case Test","url":"startest/test_case.html#Test"},{"doc":"startest/test_case","title":"TestBody","content":"pub type TestBody =\n  fn() -&gt; Nil\n\n\nSynonyms:\nstartest/test_case.TestBody\nstartest/test_case TestBody","url":"startest/test_case.html#TestBody"},{"doc":"startest/test_case","title":"TestOutcome","content":"pub type TestOutcome {\n  Passed\n  Failed(TestFailure)\n  Skipped\n}\n The outcome of a `Test` that has been run.\nPassed\n\n\nFailed(TestFailure)\n\n\nSkipped\n\n\nSynonyms:\nstartest/test_case.TestOutcome\nstartest/test_case TestOutcome","url":"startest/test_case.html#TestOutcome"},{"doc":"startest/test_case","title":"decode_test","content":"pub fn decode_test(\n  value: Dynamic,\n) -&gt; Result(Test, List(DecodeError))\n\nSynonyms:\nstartest/test_case.decode_test\nstartest/test_case decode_test","url":"startest/test_case.html#decode_test"},{"doc":"startest/test_case","title":"startest/test_case","content":"","url":"startest/test_case.html"},{"doc":"startest/reporters","title":"Reporter","content":"pub type Reporter {\n  Reporter(\n    report: fn(ReporterContext, ExecutedTest) -&gt; Nil,\n    finished: fn(ReporterContext) -&gt; Nil,\n  )\n}\n\nReporter(\n  report: fn(ReporterContext, ExecutedTest) -&gt; Nil,\n  finished: fn(ReporterContext) -&gt; Nil,\n)\n\n\nSynonyms:\nstartest/reporters.Reporter\nstartest/reporters Reporter","url":"startest/reporters.html#Reporter"},{"doc":"startest/reporters","title":"ReporterContext","content":"pub type ReporterContext {\n  ReporterContext(logger: Logger)\n}\n\nReporterContext(logger: Logger)\n\n\nSynonyms:\nstartest/reporters.ReporterContext\nstartest/reporters ReporterContext","url":"startest/reporters.html#ReporterContext"},{"doc":"startest/reporters","title":"startest/reporters","content":"","url":"startest/reporters.html"},{"doc":"startest/config","title":"Config","content":"pub type Config {\n  Config(\n    reporters: List(Reporter),\n    discover_describe_tests_pattern: Regex,\n    discover_standalone_tests_pattern: Regex,\n    filters: List(String),\n    test_name_pattern: Option(String),\n  )\n}\n\nConfig(\n  reporters: List(Reporter),\n  discover_describe_tests_pattern: Regex,\n  discover_standalone_tests_pattern: Regex,\n  filters: List(String),\n  test_name_pattern: Option(String),\n)\n\nreporters\n&lt;p&gt;The list of reporters to use to report test results.&lt;/p&gt;\n\ndiscover_describe_tests_pattern\n&lt;p&gt;The pattern to use when discovering tests using the &lt;code&gt;describe&lt;/code&gt; API.&lt;/p&gt;\n&lt;p&gt;If a function’s name matches the pattern it will be evaluated and expected\nto return a &lt;code&gt;TestTree&lt;/code&gt; (like the ones returned by &lt;code&gt;describe&lt;/code&gt; or &lt;code&gt;it&lt;/code&gt;).&lt;/p&gt;\n\ndiscover_standalone_tests_pattern\n&lt;p&gt;The pattern to use when discovering tests defined using standalone functions.&lt;/p&gt;\n&lt;p&gt;If a function’s name matches the pattern it will be run as a test.&lt;/p&gt;\n\nfilters\n&lt;p&gt;The list of test filepath filters.&lt;/p&gt;\n&lt;p&gt;Each filter is matched against a test file’s path to determine whether the\ntests in that file should be run.&lt;/p&gt;\n\ntest_name_pattern\n&lt;p&gt;The pattern to use to filter test names.&lt;/p&gt;\n\nSynonyms:\nstartest/config.Config\nstartest/config Config","url":"startest/config.html#Config"},{"doc":"startest/config","title":"with_discover_describe_tests_pattern","content":"pub fn with_discover_describe_tests_pattern(\n  config: Config,\n  discover_describe_tests_pattern: Regex,\n) -&gt; Config\n Updates the given `Config` with the specified `discover_describe_tests_pattern`.\nSynonyms:\nstartest/config.with_discover_describe_tests_pattern\nstartest/config with_discover_describe_tests_pattern","url":"startest/config.html#with_discover_describe_tests_pattern"},{"doc":"startest/config","title":"with_discover_standalone_tests_pattern","content":"pub fn with_discover_standalone_tests_pattern(\n  config: Config,\n  discover_standalone_tests_pattern: Regex,\n) -&gt; Config\n Updates the given `Config` with the specified `discover_standalone_tests_pattern`.\nSynonyms:\nstartest/config.with_discover_standalone_tests_pattern\nstartest/config with_discover_standalone_tests_pattern","url":"startest/config.html#with_discover_standalone_tests_pattern"},{"doc":"startest/config","title":"with_filters","content":"pub fn with_filters(\n  config: Config,\n  filters: List(String),\n) -&gt; Config\n Updates the given `Config` with the specified `filters`.\nSynonyms:\nstartest/config.with_filters\nstartest/config with_filters","url":"startest/config.html#with_filters"},{"doc":"startest/config","title":"with_reporters","content":"pub fn with_reporters(\n  config: Config,\n  reporters: List(Reporter),\n) -&gt; Config\n Updates the given `Config` with the specified `reporters`.\nSynonyms:\nstartest/config.with_reporters\nstartest/config with_reporters","url":"startest/config.html#with_reporters"},{"doc":"startest/config","title":"with_test_name_pattern","content":"pub fn with_test_name_pattern(\n  config: Config,\n  test_name_pattern: Option(String),\n) -&gt; Config\n Updates the given `Config` with the specified `test_name_pattern`.\nSynonyms:\nstartest/config.with_test_name_pattern\nstartest/config with_test_name_pattern","url":"startest/config.html#with_test_name_pattern"},{"doc":"startest/config","title":"startest/config","content":"","url":"startest/config.html"},{"doc":"startest/context","title":"Context","content":"pub type Context {\n  Context(\n    config: Config,\n    clock: Clock,\n    logger: Logger,\n    started_at: Time,\n  )\n}\n The Startest context.\nContext(\n  config: Config,\n  clock: Clock,\n  logger: Logger,\n  started_at: Time,\n)\n\n\nSynonyms:\nstartest/context.Context\nstartest/context Context","url":"startest/context.html#Context"},{"doc":"startest/context","title":"startest/context","content":"","url":"startest/context.html"},{"doc":"startest/test_tree","title":"TestTree","content":"pub type TestTree {\n  Suite(name: String, suite: List(TestTree))\n  Test(Test)\n}\n\nSuite(name: String, suite: List(TestTree))\n\n\nTest(Test)\n\n\nSynonyms:\nstartest/test_tree.TestTree\nstartest/test_tree TestTree","url":"startest/test_tree.html#TestTree"},{"doc":"startest/test_tree","title":"all_tests","content":"pub fn all_tests(tree: TestTree) -&gt; List(#(String, Test))\n\nSynonyms:\nstartest/test_tree.all_tests\nstartest/test_tree all_tests","url":"startest/test_tree.html#all_tests"},{"doc":"startest/test_tree","title":"decode_test_tree","content":"pub fn decode_test_tree(\n  value: Dynamic,\n) -&gt; Result(TestTree, List(DecodeError))\n\nSynonyms:\nstartest/test_tree.decode_test_tree\nstartest/test_tree decode_test_tree","url":"startest/test_tree.html#decode_test_tree"},{"doc":"startest/test_tree","title":"startest/test_tree","content":"","url":"startest/test_tree.html"},{"doc":"startest/locator","title":"TestFile","content":"pub type TestFile {\n  TestFile(\n    module_name: String,\n    filepath: String,\n    tests: List(TestTree),\n    collect_duration: Duration,\n  )\n}\n A file that contains tests.\nTestFile(\n  module_name: String,\n  filepath: String,\n  tests: List(TestTree),\n  collect_duration: Duration,\n)\n\nmodule_name\n&lt;p&gt;The name of the Gleam module.&lt;/p&gt;\n\nfilepath\n&lt;p&gt;The filepath to the &lt;code&gt;.gleam&lt;/code&gt; file.&lt;/p&gt;\n\ntests\n&lt;p&gt;The list of tests in the file.&lt;/p&gt;\n\ncollect_duration\n&lt;p&gt;The time it took to collect the tests in the file.&lt;/p&gt;\n\nSynonyms:\nstartest/locator.TestFile\nstartest/locator TestFile","url":"startest/locator.html#TestFile"},{"doc":"startest/locator","title":"TestFunction","content":"pub type TestFunction {\n  TestFunction(\n    module_name: String,\n    name: String,\n    body: fn() -&gt; Dynamic,\n  )\n}\n\nTestFunction(\n  module_name: String,\n  name: String,\n  body: fn() -&gt; Dynamic,\n)\n\n\nSynonyms:\nstartest/locator.TestFunction\nstartest/locator TestFunction","url":"startest/locator.html#TestFunction"},{"doc":"startest/locator","title":"TestSourceFile","content":"pub type TestSourceFile {\n  TestSourceFile(\n    module_name: String,\n    filepath: String,\n    tests: List(TestFunction),\n  )\n}\n A file in the `test/` directory that likely contains tests.\nTestSourceFile(\n  module_name: String,\n  filepath: String,\n  tests: List(TestFunction),\n)\n\nmodule_name\n&lt;p&gt;The name of the Gleam module.&lt;/p&gt;\n\nfilepath\n&lt;p&gt;The filepath to the &lt;code&gt;.gleam&lt;/code&gt; file.&lt;/p&gt;\n\ntests\n&lt;p&gt;The list of tests in the file.&lt;/p&gt;\n\nSynonyms:\nstartest/locator.TestSourceFile\nstartest/locator TestSourceFile","url":"startest/locator.html#TestSourceFile"},{"doc":"startest/locator","title":"identify_tests","content":"pub fn identify_tests(\n  test_files: List(TestSourceFile),\n  ctx: Context,\n) -&gt; List(TestFile)\n Identifies all of the tests contained in the given list of `TestSourceFile`s.\n\n Any files that don&#39;t have any tests will be excluded from the result.\nSynonyms:\nstartest/locator.identify_tests\nstartest/locator identify_tests","url":"startest/locator.html#identify_tests"},{"doc":"startest/locator","title":"locate_test_files","content":"pub fn locate_test_files(\n  ctx: Context,\n) -&gt; Result(List(TestSourceFile), Nil)\n Returns the list of files in the `test/` directory.\nSynonyms:\nstartest/locator.locate_test_files\nstartest/locator locate_test_files","url":"startest/locator.html#locate_test_files"},{"doc":"startest/locator","title":"startest/locator","content":"","url":"startest/locator.html"},{"doc":"startest/reporter","title":"report_summary","content":"pub fn report_summary(\n  ctx: Context,\n  test_files: List(TestFile),\n  tests: List(ExecutedTest),\n  skipped_tests: List(Test),\n  failed_tests: List(#(Test, TestFailure)),\n  discovery_duration: Duration,\n  execution_duration: Duration,\n  reporting_duration: Duration,\n) -&gt; Nil\n\nSynonyms:\nstartest/reporter.report_summary\nstartest/reporter report_summary","url":"startest/reporter.html#report_summary"},{"doc":"startest/reporter","title":"startest/reporter","content":"","url":"startest/reporter.html"},{"doc":"startest/cli","title":"run","content":"pub fn run(config: Config) -&gt; Nil\n Runs the Startest CLI.\nSynonyms:\nstartest/cli.run\nstartest/cli run","url":"startest/cli.html#run"},{"doc":"startest/cli","title":"startest/cli","content":" The Startest command line interface (CLI).","url":"startest/cli.html"},{"doc":"startest/reporters/default","title":"new","content":"pub fn new() -&gt; Reporter\n\nSynonyms:\nstartest/reporters/default.new\nstartest/reporters/default new","url":"startest/reporters/default.html#new"},{"doc":"startest/reporters/default","title":"startest/reporters/default","content":"","url":"startest/reporters/default.html"},{"doc":"startest","title":"default_config","content":"pub fn default_config() -&gt; Config\n Returns the default Startest config.\nSynonyms:\nstartest.default_config\nstartest default_config","url":"startest.html#default_config"},{"doc":"startest","title":"describe","content":"pub fn describe(name: String, suite: List(TestTree)) -&gt; TestTree\n Defines a new test suite with the given name.\n\n A suite is a way of grouping related tests together.\n\n `describe`s may also be nested in other `describe`s to form a hierarchy of tests.\nSynonyms:\nstartest.describe\nstartest describe","url":"startest.html#describe"},{"doc":"startest","title":"it","content":"pub fn it(name: String, body: fn() -&gt; Nil) -&gt; TestTree\n Defines a test with the given name.\nSynonyms:\nstartest.it\nstartest it","url":"startest.html#it"},{"doc":"startest","title":"run","content":"pub fn run(config: Config) -&gt; Nil\n Runs Startest with the provided list of tests.\nSynonyms:\nstartest.run\nstartest run","url":"startest.html#run"},{"doc":"startest","title":"xit","content":"pub fn xit(name: String, body: fn() -&gt; Nil) -&gt; TestTree\n Skips a test defined using `it`.\n\n This can be used to skip running certain tests, but without deleting the code.\n For instance, you might want to do this if a test is flaky and you want to stop\n running it temporarily until it can be fixed.\nSynonyms:\nstartest.xit\nstartest xit","url":"startest.html#xit"},{"doc":"startest","title":"startest","content":"","url":"startest.html"},{"doc":"startest/expect","title":"list_to_contain","content":"pub fn list_to_contain(actual: List(a), expected: a) -&gt; Nil\n Asserts that the given list contains the expected element.\nSynonyms:\nstartest/expect.list_to_contain\nstartest/expect list_to_contain","url":"startest/expect.html#list_to_contain"},{"doc":"startest/expect","title":"list_to_not_contain","content":"pub fn list_to_not_contain(actual: List(a), expected: a) -&gt; Nil\n Asserts that the given list does not contain the expected element.\nSynonyms:\nstartest/expect.list_to_not_contain\nstartest/expect list_to_not_contain","url":"startest/expect.html#list_to_not_contain"},{"doc":"startest/expect","title":"string_to_contain","content":"pub fn string_to_contain(actual: String, expected: String) -&gt; Nil\n Asserts that the given string contains the expected string.\nSynonyms:\nstartest/expect.string_to_contain\nstartest/expect string_to_contain","url":"startest/expect.html#string_to_contain"},{"doc":"startest/expect","title":"string_to_end_with","content":"pub fn string_to_end_with(\n  actual: String,\n  expected: String,\n) -&gt; Nil\n Asserts that the given string ends with the expected string.\nSynonyms:\nstartest/expect.string_to_end_with\nstartest/expect string_to_end_with","url":"startest/expect.html#string_to_end_with"},{"doc":"startest/expect","title":"string_to_not_contain","content":"pub fn string_to_not_contain(\n  actual: String,\n  expected: String,\n) -&gt; Nil\n Asserts that the given string does not contain the expected string.\nSynonyms:\nstartest/expect.string_to_not_contain\nstartest/expect string_to_not_contain","url":"startest/expect.html#string_to_not_contain"},{"doc":"startest/expect","title":"string_to_start_with","content":"pub fn string_to_start_with(\n  actual: String,\n  expected: String,\n) -&gt; Nil\n Asserts that the given string starts with the expected string.\nSynonyms:\nstartest/expect.string_to_start_with\nstartest/expect string_to_start_with","url":"startest/expect.html#string_to_start_with"},{"doc":"startest/expect","title":"to_be_error","content":"pub fn to_be_error(actual: Result(a, b)) -&gt; b\n Asserts that the given value is `Error(_)`.\nSynonyms:\nstartest/expect.to_be_error\nstartest/expect to_be_error","url":"startest/expect.html#to_be_error"},{"doc":"startest/expect","title":"to_be_false","content":"pub fn to_be_false(actual: Bool) -&gt; Nil\n Asserts that the given value is `False`.\nSynonyms:\nstartest/expect.to_be_false\nstartest/expect to_be_false","url":"startest/expect.html#to_be_false"},{"doc":"startest/expect","title":"to_be_none","content":"pub fn to_be_none(actual: Option(a)) -&gt; Nil\n Asserts that the given value is `None`.\nSynonyms:\nstartest/expect.to_be_none\nstartest/expect to_be_none","url":"startest/expect.html#to_be_none"},{"doc":"startest/expect","title":"to_be_ok","content":"pub fn to_be_ok(actual: Result(a, b)) -&gt; a\n Asserts that the given value is `Ok(_)`.\nSynonyms:\nstartest/expect.to_be_ok\nstartest/expect to_be_ok","url":"startest/expect.html#to_be_ok"},{"doc":"startest/expect","title":"to_be_some","content":"pub fn to_be_some(actual: Option(a)) -&gt; a\n Asserts that the given value is `Some(_)`.\nSynonyms:\nstartest/expect.to_be_some\nstartest/expect to_be_some","url":"startest/expect.html#to_be_some"},{"doc":"startest/expect","title":"to_be_true","content":"pub fn to_be_true(actual: Bool) -&gt; Nil\n Asserts that the given value is `True`.\nSynonyms:\nstartest/expect.to_be_true\nstartest/expect to_be_true","url":"startest/expect.html#to_be_true"},{"doc":"startest/expect","title":"to_equal","content":"pub fn to_equal(actual: a, expected expected: a) -&gt; Nil\n Asserts that the given value is equal to the expected value.\nSynonyms:\nstartest/expect.to_equal\nstartest/expect to_equal","url":"startest/expect.html#to_equal"},{"doc":"startest/expect","title":"to_loosely_equal","content":"pub fn to_loosely_equal(\n  actual: Float,\n  expected expected: Float,\n  tolerating tolerance: Float,\n) -&gt; Nil\n Asserts that the given `Float` is equal to the expected `Float` within the\n provided tolerance.\nSynonyms:\nstartest/expect.to_loosely_equal\nstartest/expect to_loosely_equal","url":"startest/expect.html#to_loosely_equal"},{"doc":"startest/expect","title":"to_not_equal","content":"pub fn to_not_equal(actual: a, expected expected: a) -&gt; Nil\n Asserts that the given value is not equal to the expected value.\nSynonyms:\nstartest/expect.to_not_equal\nstartest/expect to_not_equal","url":"startest/expect.html#to_not_equal"},{"doc":"startest/expect","title":"to_not_throw","content":"pub fn to_not_throw(f: fn() -&gt; a) -&gt; a\n Asserts that the given function does not throw an error.\nSynonyms:\nstartest/expect.to_not_throw\nstartest/expect to_not_throw","url":"startest/expect.html#to_not_throw"},{"doc":"startest/expect","title":"to_throw","content":"pub fn to_throw(f: fn() -&gt; a) -&gt; Nil\n Asserts that the given function throws an error.\nSynonyms:\nstartest/expect.to_throw\nstartest/expect to_throw","url":"startest/expect.html#to_throw"},{"doc":"startest/expect","title":"startest/expect","content":" Assertions to be used in tests.","url":"startest/expect.html"},{"doc":"startest/reporters/dot","title":"new","content":"pub fn new() -&gt; Reporter\n\nSynonyms:\nstartest/reporters/dot.new\nstartest/reporters/dot new","url":"startest/reporters/dot.html#new"},{"doc":"startest/reporters/dot","title":"startest/reporters/dot","content":"","url":"startest/reporters/dot.html"}]);